@@ -52,6 +52,7 @@ sa_logger = None
 # Singleton repository references, instantiated via get_xxxx_repository()
 #   functions below.  Please keep this list in alphabetical order.
 _CA_REPOSITORY = None
+_CONTAINER_ACL_USER_REPOSITORY = None
 _CONTAINER_ACL_REPOSITORY = None
 _CONTAINER_CONSUMER_REPOSITORY = None
 _CONTAINER_REPOSITORY = None
@@ -66,6 +67,7 @@ _PREFERRED_CA_REPOSITORY = None
 _PROJECT_REPOSITORY = None
 _PROJECT_CA_REPOSITORY = None
 _PROJECT_QUOTAS_REPOSITORY = None
+_SECRET_ACL_USER_REPOSITORY = None
 _SECRET_ACL_REPOSITORY = None
 _SECRET_META_REPOSITORY = None
 _SECRET_USER_META_REPOSITORY = None
@@ -204,6 +206,13 @@ def _get_engine(engine):
     return engine
 
 
+def model_query(model, *args, **kwargs):
+    """Query helper for simpler session usage."""
+    session = kwargs.get('session')
+    query = session.query(model, *args)
+    return query
+
+
 def _initialize_secret_stores_data():
     """Initializes secret stores data in database.
 
@@ -418,6 +427,23 @@ class BaseRepo(object):
 
         return entity
 
+    def update_from(self, model_class, entity_id, values, session=None):
+        if id in values:
+            raise Exception('Cannot update id')
+        LOG.debug('Begin update from ...')
+        session = self.get_session(session=session)
+
+        query = session.query(model_class)
+        query = query.filter_by(id=entity_id)
+        try:
+            LOG.debug('Updating value ...')
+            entity = query.one()
+        except sa_orm.exc.NoResultFound:
+            raise exception.NotFound('DB Entity with id {0} not '
+                                     'found'.format(entity_id))
+        self._update_values(entity, values)
+        entity.save()
+
     def save(self, entity):
         """Saves the state of the entity."""
         entity.updated_at = timeutils.utcnow()
@@ -1984,6 +2010,26 @@ class SecretACLRepo(BaseRepo):
             entity.delete(session=session)
 
 
+class SecretACLUserRepo(BaseRepo):
+    """Repository for the SecretACLUser entity."""
+
+    def _do_entity_name(self):
+        """Sub-class hook: return entity name, such as for debugging."""
+        return "SecretACLUser"
+
+    def _do_build_get_query(self, entity_id, external_project_id, session):
+        """Sub-class hook: build a retrieve query."""
+
+        query = session.query(models.SecretACLUser)
+        query = query.filter_by(id=entity_id)
+
+        return query
+
+    def _do_validate(self, values):
+        """Sub-class hook: validate values."""
+        pass
+
+
 class ContainerACLRepo(BaseRepo):
     """Repository for the ContainerACL entity.
 
@@ -2080,6 +2126,25 @@ class ContainerACLRepo(BaseRepo):
             entity.delete(session=session)
 
 
+class ContainerACLUserRepo(BaseRepo):
+    """Repository for ContainerACLUser entity."""
+    def _do_entity_name(self):
+        """Sub-class hook: return entity name, such as for debugging."""
+        return "ContainerACLUser"
+
+    def _do_build_get_query(self, entity_id, external_project_id, session):
+        """Sub-class hook: build a retrieve query."""
+
+        query = session.query(models.ContainerACLUser)
+        query = query.filter_by(id=entity_id)
+
+        return query
+
+    def _do_validate(self, values):
+        """Sub-class hook: validate values."""
+        pass
+
+
 class ProjectQuotasRepo(BaseRepo):
     """Repository for the ProjectQuotas entity."""
     def _do_entity_name(self):
@@ -2382,6 +2447,13 @@ def get_container_secret_repository():
     return _get_repository(_CONTAINER_SECRET_REPOSITORY, ContainerSecretRepo)
 
 
+def get_container_acl_user_repository():
+    """Returns a singleton Container-ACL-User repository instance."""
+    global _CONTAINER_ACL_USER_REPOSITORY
+    return _get_repository(_CONTAINER_ACL_USER_REPOSITORY,
+                           ContainerACLUserRepo)
+
+
 def get_encrypted_datum_repository():
     """Returns a singleton Encrypted Datum repository instance."""
     global _ENCRYPTED_DATUM_REPOSITORY
@@ -2453,6 +2525,12 @@ def get_secret_acl_repository():
     return _get_repository(_SECRET_ACL_REPOSITORY, SecretACLRepo)
 
 
+def get_secret_acl_user_repository():
+    """Returns a singleton Secret-ACL-User repository instance."""
+    global _SECRET_ACL_USER_REPOSITORY
+    return _get_repository(_SECRET_ACL_USER_REPOSITORY, SecretACLUserRepo)
+
+
 def get_secret_meta_repository():
     """Returns a singleton Secret meta repository instance."""
     global _SECRET_META_REPOSITORY
